# database.crossplane.io/v1alpha1 API Reference

Package v1alpha1 contains portable resource claims for database services such as MySQL or PostgreSQL.

This API group contains the following Crossplane resources:

* [MySQLInstance](#MySQLInstance)
* [MySQLInstanceClass](#MySQLInstanceClass)
* [PostgreSQLInstance](#PostgreSQLInstance)
* [PostgreSQLInstanceClass](#PostgreSQLInstanceClass)

## MySQLInstance

A MySQLInstance is a portable resource claim that may be satisfied by binding to a MySQL managed resource such as an AWS RDS instance or a GCP CloudSQL instance.


Name | Type | Description
-----|------|------------
`apiVersion` | string | `database.crossplane.io/v1alpha1`
`kind` | string | `MySQLInstance`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.
`spec` | [MySQLInstanceSpec](#MySQLInstanceSpec) | MySQLInstanceSpec specifies the desired state of a MySQLInstance.
`status` | [v1alpha1.ResourceClaimStatus](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourceclaimstatus) | 



## MySQLInstanceClass

MySQLInstanceClass contains a namespace-scoped portable class for MySQLInstance


Name | Type | Description
-----|------|------------
`apiVersion` | string | `database.crossplane.io/v1alpha1`
`kind` | string | `MySQLInstanceClass`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.


MySQLInstanceClass supports all fields of:

* [v1alpha1.PortableClass](../crossplane-runtime/core-crossplane-io-v1alpha1.md#portableclass)


## PostgreSQLInstance

A PostgreSQLInstance is a portable resource claim that may be satisfied by binding to a PostgreSQL managed resource such as an AWS RDS instance or a GCP CloudSQL instance. PostgreSQLInstance is the CRD type for abstract PostgreSQL database instances


Name | Type | Description
-----|------|------------
`apiVersion` | string | `database.crossplane.io/v1alpha1`
`kind` | string | `PostgreSQLInstance`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.
`spec` | [PostgreSQLInstanceSpec](#PostgreSQLInstanceSpec) | PostgreSQLInstanceSpec specifies the desired state of a PostgreSQLInstance. PostgreSQLInstance.
`status` | [v1alpha1.ResourceClaimStatus](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourceclaimstatus) | 



## PostgreSQLInstanceClass

PostgreSQLInstanceClass contains a namespace-scoped portable class for PostgreSQLInstance


Name | Type | Description
-----|------|------------
`apiVersion` | string | `database.crossplane.io/v1alpha1`
`kind` | string | `PostgreSQLInstanceClass`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.


PostgreSQLInstanceClass supports all fields of:

* [v1alpha1.PortableClass](../crossplane-runtime/core-crossplane-io-v1alpha1.md#portableclass)


## MySQLInstanceSpec

MySQLInstanceSpec specifies the desired state of a MySQLInstance.

Appears in:

* [MySQLInstance](#MySQLInstance)


Name | Type | Description
-----|------|------------
`engineVersion` | string | EngineVersion specifies the desired MySQL engine version, e.g. 5.7.


MySQLInstanceSpec supports all fields of:

* [v1alpha1.ResourceClaimSpec](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourceclaimspec)


## PostgreSQLInstanceSpec

PostgreSQLInstanceSpec specifies the desired state of a PostgreSQLInstance. PostgreSQLInstance.

Appears in:

* [PostgreSQLInstance](#PostgreSQLInstance)


Name | Type | Description
-----|------|------------
`engineVersion` | string | EngineVersion specifies the desired PostgreSQL engine version, e.g. 9.6.


PostgreSQLInstanceSpec supports all fields of:

* [v1alpha1.ResourceClaimSpec](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourceclaimspec)


This API documentation was generated by `crossdocs`.