# database.aws.crossplane.io/v1alpha2 API Reference

Package v1alpha2 contains managed resources for AWS database services such as RDS.

This API group contains the following Crossplane resources:

* [RDSInstance](#RDSInstance)
* [RDSInstanceClass](#RDSInstanceClass)

## RDSInstance

An RDSInstance is a managed resource that represents an AWS Relational Database Service instance.


Name | Type | Description
-----|------|------------
`apiVersion` | string | `database.aws.crossplane.io/v1alpha2`
`kind` | string | `RDSInstance`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.
`spec` | [RDSInstanceSpec](#RDSInstanceSpec) | An RDSInstanceSpec defines the desired state of an RDSInstance.
`status` | [RDSInstanceStatus](#RDSInstanceStatus) | An RDSInstanceStatus represents the observed state of an RDSInstance.



## RDSInstanceClass

An RDSInstanceClass is a non-portable resource class. It defines the desired spec of resource claims that use it to dynamically provision a managed resource.


Name | Type | Description
-----|------|------------
`apiVersion` | string | `database.aws.crossplane.io/v1alpha2`
`kind` | string | `RDSInstanceClass`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.
`specTemplate` | [RDSInstanceClassSpecTemplate](#RDSInstanceClassSpecTemplate) | SpecTemplate is a template for the spec of a dynamically provisioned RDSInstance.



## RDSInstanceClassSpecTemplate

An RDSInstanceClassSpecTemplate is a template for the spec of a dynamically provisioned RDSInstance.

Appears in:

* [RDSInstanceClass](#RDSInstanceClass)




RDSInstanceClassSpecTemplate supports all fields of:

* [v1alpha1.NonPortableClassSpecTemplate](../crossplane-runtime/core-crossplane-io-v1alpha1.md#nonportableclassspectemplate)
* [RDSInstanceParameters](#RDSInstanceParameters)


## RDSInstanceParameters

RDSInstanceParameters define the desired state of an AWS Relational Database Service instance.

Appears in:

* [RDSInstanceClassSpecTemplate](#RDSInstanceClassSpecTemplate)
* [RDSInstanceSpec](#RDSInstanceSpec)


Name | Type | Description
-----|------|------------
`masterUsername` | string | MasterUsername for this RDSInstance.
`engine` | string | Engine for this RDSInstance - either mysql or postgres.
`engineVersion` | Optional string | EngineVersion for this RDS instance, for example &#34;5.6&#34;.
`class` | string | Class of this RDS instance, for example &#34;db.t2.micro&#34;.
`size` | int64 | Size in GB of this RDS instance.
`subnetGroupName` | Optional string | SubnetGroupName specifies a database subnet group for the RDS instance. The new instance is created in the VPC associated with the DB subnet group. If no DB subnet group is specified, then the instance is not created in a VPC.
`securityGroups` | Optional []string | SecurityGroups that will allow the RDS instance to be accessed over the network.



## RDSInstanceSpec

An RDSInstanceSpec defines the desired state of an RDSInstance.

Appears in:

* [RDSInstance](#RDSInstance)




RDSInstanceSpec supports all fields of:

* [v1alpha1.ResourceSpec](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourcespec)
* [RDSInstanceParameters](#RDSInstanceParameters)


## RDSInstanceState

RDSInstanceState represents the state of an RDS instance. Alias of string.


## RDSInstanceStatus

An RDSInstanceStatus represents the observed state of an RDSInstance.

Appears in:

* [RDSInstance](#RDSInstance)


Name | Type | Description
-----|------|------------
`state` | string | State of this RDS instance.
`providerID` | string | ProviderID is the AWS identifier for this RDS instance.
`instanceName` | string | InstanceName of this RDS instance.
`endpoint` | string | Endpoint of this RDS instance.


RDSInstanceStatus supports all fields of:

* [v1alpha1.ResourceStatus](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourcestatus)


This API documentation was generated by `crossdocs`.