# compute.aws.crossplane.io/v1alpha3 API Reference

Package v1alpha3 contains managed resources for AWS compute services such as EKS.

This API group contains the following Crossplane resources:

* [EKSCluster](#EKSCluster)
* [EKSClusterClass](#EKSClusterClass)

## EKSCluster

An EKSCluster is a managed resource that represents an AWS Elastic Kubernetes Service cluster.


Name | Type | Description
-----|------|------------
`apiVersion` | string | `compute.aws.crossplane.io/v1alpha3`
`kind` | string | `EKSCluster`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.
`spec` | [EKSClusterSpec](#EKSClusterSpec) | An EKSClusterSpec defines the desired state of an EKSCluster.
`status` | [EKSClusterStatus](#EKSClusterStatus) | An EKSClusterStatus represents the observed state of an EKSCluster.



## EKSClusterClass

An EKSClusterClass is a resource class. It defines the desired spec of resource claims that use it to dynamically provision a managed resource.


Name | Type | Description
-----|------|------------
`apiVersion` | string | `compute.aws.crossplane.io/v1alpha3`
`kind` | string | `EKSClusterClass`
`metadata` | [meta/v1.ObjectMeta](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.15/#objectmeta-v1-meta) | Kubernetes object metadata.
`specTemplate` | [EKSClusterClassSpecTemplate](#EKSClusterClassSpecTemplate) | SpecTemplate is a template for the spec of a dynamically provisioned EKSCluster.



## EKSClusterClassSpecTemplate

An EKSClusterClassSpecTemplate is a template for the spec of a dynamically provisioned EKSCluster.

Appears in:

* [EKSClusterClass](#EKSClusterClass)




EKSClusterClassSpecTemplate supports all fields of:

* [v1alpha1.ClassSpecTemplate](../crossplane-runtime/core-crossplane-io-v1alpha1.md#classspectemplate)
* [EKSClusterParameters](#EKSClusterParameters)


## EKSClusterParameters

EKSClusterParameters define the desired state of an AWS Elastic Kubernetes Service cluster.

Appears in:

* [EKSClusterClassSpecTemplate](#EKSClusterClassSpecTemplate)
* [EKSClusterSpec](#EKSClusterSpec)


Name | Type | Description
-----|------|------------
`region` | [EKSRegion](#EKSRegion) | Region for this EKS Cluster.
`roleARN` | string | RoleARN: The Amazon Resource Name (ARN) of the IAM role that provides permis sions for Amazon EKS to make calls to other AWS  API  operations on your behalf. For more information, see &#39;Amazon EKS Service IAM Role&#39; in the Amazon EKS User Guide.
`roleARNRef` | [IAMRoleARNReferencerForEKSCluster](#IAMRoleARNReferencerForEKSCluster) | RoleARNRef references to an IAMRole to retrieve its ARN
`vpcId` | string | VPCID is the ID of the VPC.
`vpcIdRef` | [VPCIDReferencerForEKSCluster](#VPCIDReferencerForEKSCluster) | VPCIDRef references to a VPC to and retrieves its vpcId
`subnetIds` | []string | SubnetIDs of this EKS cluster.
`subnetIdRefs` | [[]*github.com/crossplaneio/stack-aws/apis/compute/v1alpha3.SubnetIDReferencerForEKSCluster](#*github.com/crossplaneio/stack-aws/apis/compute/v1alpha3.SubnetIDReferencerForEKSCluster) | SubnetIDRefs is a set of referencers that each retrieve the subnetID from the referenced Subnet
`securityGroupIds` | []string | SecurityGroupIDs of this EKS cluster.
`securityGroupIdRefs` | [[]*github.com/crossplaneio/stack-aws/apis/compute/v1alpha3.SecurityGroupIDReferencerForEKSCluster](#*github.com/crossplaneio/stack-aws/apis/compute/v1alpha3.SecurityGroupIDReferencerForEKSCluster) | SecurityGroupIDRefs is a set of referencers that each retrieve the ID from the referenced SecurityGroup
`clusterVersion` | Optional string | ClusterVersion: The desired Kubernetes version of this EKS Cluster. If you do not specify a value here, the latest version available is used.
`workerNodes` | [WorkerNodesSpec](#WorkerNodesSpec) | WorkerNodes configuration for cloudformation
`mapRoles` | Optional [[]MapRole](#MapRole) | MapRoles map AWS roles to one or more Kubernetes groups. A Default role that allows nodes access to communicate with master is autogenerated when a node pool comes online.
`mapUsers` | Optional [[]MapUser](#MapUser) | MapUsers map AWS users to one or more Kubernetes groups.



## EKSClusterSpec

An EKSClusterSpec defines the desired state of an EKSCluster.

Appears in:

* [EKSCluster](#EKSCluster)




EKSClusterSpec supports all fields of:

* [v1alpha1.ResourceSpec](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourcespec)
* [EKSClusterParameters](#EKSClusterParameters)


## EKSClusterStatus

An EKSClusterStatus represents the observed state of an EKSCluster.

Appears in:

* [EKSCluster](#EKSCluster)


Name | Type | Description
-----|------|------------
`state` | string | State of the cluster.
`resourceName` | string | ClusterName of the cluster.
`resourceVersion` | string | ClusterVersion of the cluster.
`endpoint` | string | Endpoint for connecting to the cluster.
`cloudformationStackId` | string | CloudFormationStackID of the Stack used to create node groups.


EKSClusterStatus supports all fields of:

* [v1alpha1.ResourceStatus](../crossplane-runtime/core-crossplane-io-v1alpha1.md#resourcestatus)


## EKSRegion

EKSRegion represents an EKS enabled AWS region. Alias of string.

Appears in:

* [EKSClusterParameters](#EKSClusterParameters)


## IAMRoleARNReferencerForEKSCluster

IAMRoleARNReferencerForEKSCluster is an attribute referencer that retrieves IAMRoleARN from a referenced IAMRole

Appears in:

* [EKSClusterParameters](#EKSClusterParameters)




IAMRoleARNReferencerForEKSCluster supports all fields of:

* github.com/crossplaneio/stack-aws/apis/identity/v1alpha3.IAMRoleARNReferencer


## MapRole

MapRole maps an AWS IAM role to one or more Kubernetes groups. See https://docs.aws.amazon.com/eks/latest/userguide/add-user-role.html and https://github.com/kubernetes-sigs/aws-iam-authenticator/blob/master/README.md

Appears in:

* [EKSClusterParameters](#EKSClusterParameters)


Name | Type | Description
-----|------|------------
`rolearn` | string | RoleARN to match, e.g. &#39;arn:aws:iam::000000000000:role/KubernetesNode&#39;.
`username` | string | Username (in Kubernetes) the RoleARN should map to.
`groups` | []string | Groups (in Kubernetes) the RoleARN should map to.



## MapUser

MapUser maps an AWS IAM user to one or more Kubernetes groups. See https://docs.aws.amazon.com/eks/latest/userguide/add-user-role.html and https://github.com/kubernetes-sigs/aws-iam-authenticator/blob/master/README.md

Appears in:

* [EKSClusterParameters](#EKSClusterParameters)


Name | Type | Description
-----|------|------------
`userarn` | string | UserARN to match, e.g. &#39;arn:aws:iam::000000000000:user/Alice&#39;
`username` | string | Username (in Kubernetes) the UserARN should map to.
`groups` | []string | Groups (in Kubernetes) the UserARN should map to.



## SecurityGroupIDReferencerForEKSCluster

SecurityGroupIDReferencerForEKSCluster is an attribute referencer that resolves ID from a referenced SecurityGroup




SecurityGroupIDReferencerForEKSCluster supports all fields of:

* github.com/crossplaneio/stack-aws/apis/network/v1alpha3.SecurityGroupIDReferencer


## SecurityGroupIDReferencerForEKSWorkerNodes

SecurityGroupIDReferencerForEKSWorkerNodes is an attribute referencer that resolves ID from a referenced SecurityGroup

Appears in:

* [WorkerNodesSpec](#WorkerNodesSpec)




SecurityGroupIDReferencerForEKSWorkerNodes supports all fields of:

* github.com/crossplaneio/stack-aws/apis/network/v1alpha3.SecurityGroupIDReferencer


## SubnetIDReferencerForEKSCluster

SubnetIDReferencerForEKSCluster is an attribute referencer that resolves SubnetID from a referenced Subnet




SubnetIDReferencerForEKSCluster supports all fields of:

* github.com/crossplaneio/stack-aws/apis/network/v1alpha3.SubnetIDReferencer


## VPCIDReferencerForEKSCluster

VPCIDReferencerForEKSCluster is an attribute referencer that resolves VPCID from a referenced VPC

Appears in:

* [EKSClusterParameters](#EKSClusterParameters)




VPCIDReferencerForEKSCluster supports all fields of:

* github.com/crossplaneio/stack-aws/apis/network/v1alpha3.VPCIDReferencer


## WorkerNodesSpec

WorkerNodesSpec - Worker node spec used to define cloudformation template that provisions workers for cluster

Appears in:

* [EKSClusterParameters](#EKSClusterParameters)


Name | Type | Description
-----|------|------------
`keyName` | Optional string | KeyName of the EC2 Key Pair to allow SSH access to the EC2 instances.
`nodeImageId` | Optional string | NodeImageId that the EC2 instances should run. Defaults to the region&#39;s standard AMI.
`nodeInstanceType` | string | NodeInstanceType of the EC2 instances.
`nodeAutoScalingGroupMinSize` | Optional int | NodeAutoScalingGroupMinSize configures the minimum size of this node group&#39;s Autoscaling Group. Defaults to 1.
`nodeAutoScalingGroupMaxSize` | Optional int | NodeAutoScalingGroupMaxSize configures the maximum size of this node group&#39;s Autoscaling Group. Defaults to 3.
`nodeVolumeSize` | Optional int | NodeVolumeSize configures the volume size in GB. Defaults to 20.
`bootstrapArguments` | Optional string | BootstrapArguments to pass to the bootstrap script. See files/bootstrap.sh in https://github.com/awslabs/amazon-eks-ami
`nodeGroupName` | Optional string | NodeGroupName is a unique identifier for the Node Group.
`clusterControlPlaneSecurityGroup` | Optional string | ClusterControlPlaneSecurityGroup configures the security group of the cluster control plane in order to allow communication to this node group.
`clusterControlPlaneSecurityGroupRef` | [SecurityGroupIDReferencerForEKSWorkerNodes](#SecurityGroupIDReferencerForEKSWorkerNodes) | ClusterControlPlaneSecurityGroupRef references to a SecurityGroup to retrieve its ID



This API documentation was generated by `crossdocs`.